package com.s3ai.controllers.tickets;

import com.s3ai.entities.Cinema;
import com.s3ai.entities.Ticket;
import com.s3ai.entities.User;
import com.s3ai.services.CinemaService;
import com.s3ai.services.TicketService;
import com.s3ai.services.UserService;

import javax.servlet.RequestDispatcher;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import java.io.IOException;
import java.util.List;
import java.util.UUID;

public class TicketsEdit extends HttpServlet {
    TicketService ticketService = TicketService.getInstance();
    CinemaService cinemaService = CinemaService.getInstance();
    UserService userService = UserService.getInstance();

    protected void doPost(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        Ticket ticket = null;
        String id = req.getParameter("id");
        String userId = req.getParameter("userId") == null ? "" : req.getParameter("userId");
        String cinemaId = req.getParameter("cinemaId") == null ? "" : req.getParameter("cinemaId");
        String movie = req.getParameter("movie") == null ? "" : req.getParameter("movie");

        var user = userService.getUserById(UUID.fromString(userId));
        var cinema = cinemaService.getCinemaById(UUID.fromString(cinemaId));

        if (null == user) {
            resp.sendError(500, "Invalid userId");
        }

        if (null == cinema) {
            resp.sendError(500, "Invalid cinemaId");
        }

        if (null == id || "".equals(id)) {
            ticket = new Ticket();
            ticket.setId(UUID.randomUUID());
            ticketService.fillTicketFields(ticket, user, cinema, movie);
            ticketService.saveTicket(ticket);
        } else {
            ticket = ticketService.getTicketById(UUID.fromString(id));
            ticketService.fillTicketFields(ticket, user, cinema, movie);
            ticketService.updateTicket(ticket);
        }
        resp.sendRedirect("/tickets");
    }

    protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        HttpSession session = req.getSession();
        String idToEdit = req.getParameter("id");
        Ticket ticket = null;
        RequestDispatcher dispatcher = req.getRequestDispatcher("/pages/tickets/edit.jsp");
        if (idToEdit != null) {
            ticket = ticketService.getTicketById(UUID.fromString(idToEdit));
        } else {
            ticket = new Ticket();
        }
        List<User> users = userService.getAllUsers();
        List<Cinema> cinemas = cinemaService.getAllCinemas();
        session.setAttribute("users", users);
        session.setAttribute("cinemas", cinemas);
        session.setAttribute("ticket", ticket);
        dispatcher.forward(req, resp);
    }
}
